@@ -1,4 +1,4 @@
-import intersection.url.url as url
+from intersection.ext import url
 from intersection import user, map
 
 class Highscore:
@@ -15,10 +15,28 @@ class Highscore:
         self.username = username
 
     def get_author(self):
-        return
+        """A method used to used to create a `User` object of the highscore author.
+
+        Usage::
+
+        >>> import intersection
+        >>> highscore = intersection.highscore.list_high_scores_on_map(mapId=413915, count=1)
+        >>> author = highscore[0].get_author()
+        >>> print(author.name)
+        """
+        return user.get_details_for_user(userId=self.userId)
 
     def get_map(self):
-        return
+        """A method used to used to create a `Map` object of the map the highscore was scored on.
+
+        Usage::
+
+        >>> import intersection
+        >>> highscore = intersection.highscore.list_high_scores_on_map(mapId=413915, count=1)
+        >>> map = highscore[0].get_map()
+        >>> print(map.name)
+        """
+        return map.get_map_details(mapId=self.mapId)
 
 def list_high_scores_on_map(**kwargs):
     """A function used to used to create a list of `Highscore` objects on a certain map.
@@ -31,7 +49,7 @@ def list_high_scores_on_map(**kwargs):
 
     >>> import intersection
     >>> highscores = intersection.highscore.list_high_scores_on_map(mapId=413915, count=5)
-    >>> for highscore in highscores: print(comment.comment)
+    >>> for highscore in highscores: print(highscore.score)
     """
 
     data = url.list_high_scores_on_map(**kwargs)
