@@ -1,4 +1,4 @@
-import intersection.url.url as url
+from intersection.ext import url
 from intersection import user, comment, highscore
 
 class Map:
@@ -28,12 +28,49 @@ class Map:
         self.authorName = authorName
 
     def get_author(self):
+        """A method used to used to create a `User` object of the map author.
+
+        Usage::
+
+        >>> import intersection
+        >>> map = intersection.map.get_map_details(mapId=413915)
+        >>> author = map.get_author()
+        >>> print(author.name)
+        """
         return user.get_details_for_user(userId=self.objectId)
 
     def get_highscore_user(self):
+        """A method used to used to create a `User` object of the person who achieved the highest score on the map.
+
+        Usage::
+
+        >>> import intersection
+        >>> map = intersection.map.get_map_details(mapId=413915)
+        >>> highscore_user = map.get_highscore_user()
+        >>> print(highscore_user.name)
+        """
         return user.get_details_for_user(userId=self.highScoreUser)
     
     def is_in_trending(self, **kwargs):
+        """A method used to used to get the trending position of a map.
+
+        `time` - alltime / month / week / day
+
+        `maxversion` - The requester's game version, so if you have version 130 of the app you will not get maps that were made using 140 and might not be possible to play. Setting something very high such as 999 will just search for everything. If not added to the request then only maps made before beta will be searched for.
+
+        `result` - Number of results to return on a page.
+
+        `page` - Index of page of results to return, starting at page 0.
+
+        `trendsystem` - 0 or 1, should always be set to 1 as that is the current version used ingame.
+
+        Usage::
+
+        >>> import intersection
+        >>> map = intersection.map.get_map_details(mapId=413915)
+        >>> is_in_trending = map.is_in_trending(time="alltime", result=5)
+        >>> print(is_in_trending)
+        """
         data = find_top_maps(**kwargs)
 
         for mapdata in data:
@@ -43,7 +80,26 @@ class Map:
         return False
 
     def get_trending_position(self, **kwargs):
-        data = find_top_maps(**kwargs)
+        """A method used to used to get the trending position of a map.
+
+        `time` - alltime / month / week / day
+
+        `maxversion` - The requester's game version, so if you have version 130 of the app you will not get maps that were made using 140 and might not be possible to play. Setting something very high such as 999 will just search for everything. If not added to the request then only maps made before beta will be searched for.
+
+        `result` - Number of results to return on a page.
+
+        `page` - Index of page of results to return, starting at page 0.
+
+        `trendsystem` - 0 or 1, should always be set to 1 as that is the current version used ingame.
+
+        Usage::
+
+        >>> import intersection
+        >>> map = intersection.map.get_map_details(mapId=413915)
+        >>> position = map.get_trending_position(time="alltime", result=5)
+        >>> print(position)
+        """
+        data = find_top_maps(gameMode=self.gameModeGroup, **kwargs)
         position = 0
 
         for mapdata in data:
@@ -52,12 +108,45 @@ class Map:
             position = position + 1
 
     def get_comments(self, **kwargs):
+        """A method used to used to create a list of `Comment` objects under a certain map.
+
+        `before` - ID of comment to fetch results after, in order to not get duplicates.
+
+        `limit` - Number of comments to return.
+
+        Usage::
+
+        >>> import intersection
+        >>> map = intersection.map.get_map_details(mapId=413915)
+        >>> comments = map.get_comments(limit=5)
+        >>> for comment in comments: print(comment.comment)
+        """
         return comment.list_comments_on_map(mapId=self.objectId, **kwargs)
     
     def get_thumbnail_url(self):
+        """A method returning the url of the thumbnail image of a map.
+
+        Usage::
+
+        >>> import intersection
+        >>> map = intersection.map.get_map_details(mapId=413915)
+        >>> thumbnail_url = map.get_thumbnail_url()
+        >>> print(thumbnail_url)
+        """
         return get_map_thumbnail_url(mapId=self.objectId)
 
     def get_highscores(self, **kwargs):
+        """A method used to used to create a list of `Highscore` objects on a certain map.
+
+        `count` - Number of high scores to get.
+
+        Usage::
+
+        >>> import intersection
+        >>> map = intersection.map.get_map_details(mapId=413915)
+        >>> highscores = map.get_highscores(count=5)
+        >>> for highscore in highscores: print(comment.comment)
+        """
         return highscore.list_high_scores_on_map(mapId=self.objectId, **kwargs)
 
 def search_for_maps(**kwargs):
@@ -127,7 +216,7 @@ def find_top_maps(**kwargs):
     Usage::
 
     >>> import intersection
-    >>> maps = intersection.map.find_top_maps(gameMode=1, time=alltime, result=5)
+    >>> maps = intersection.map.find_top_maps(gameMode=1, time="alltime", result=5)
     >>> for map in maps: print(map.name)
     """
 
