@@ -1,4 +1,4 @@
-import intersection.url.url as url
+from intersection.ext import url
 from intersection import map
 
 class User:
@@ -14,6 +14,14 @@ class User:
         self.followers = followers
 
     def get_user_maps(self, **kwargs):
+        """A method user to create a list of `Map` objects with some of the maps the user has created.
+
+        Usage::
+        >>> import intersection
+        >>> user = intersection.user.get_details_for_user(userId=2452411)
+        >>> maps = user.get_user_maps()
+        >>> for map in maps: print(map.name)
+        """
         maps = map.list_maps_by_user(userId=self.objectId, **kwargs)
         return maps
 
@@ -55,7 +63,7 @@ def get_details_for_user(**kwargs):
     Usage::
 
     >>> import intersection
-    >>> maps = intersection.user.get_details_for_user(userId=2452411)
+    >>> user = intersection.user.get_details_for_user(userId=2452411)
     >>> print(user.name)
     """
 
